@@ -35,12 +35,22 @@
 #include "esniper.h"
 
 static long getSeconds(char *timestr);
+static int checkPageType(auctionInfo *aip, int pageType, int auctionState, int auctionResult);
 
 static const char PRIVATE[] = "private auction - bidders' identities protected";
 
+/* pageType */
 #define VIEWBIDS 1
 #define VIEWTRANSACTIONS 2
 
+/* auctionState */
+#define STATE_ACTIVE 1
+#define STATE_CLOSED 2
+
+/* auctionResult */
+#define RESULT_HIGH_BIDDER 1
+#define RESULT_NONE 2
+
 #define NOTHING 0
 #define PRICE 1
 #define QUANTITY 2
@@ -59,23 +69,44 @@ parseBidHistory(memBuf_t *mp, auctionInfo *aip, time_t start, time_t *timeToFirs
 {
 	char *line;
 	char **row = NULL;
-	int rowCount;
 	int ret = 0;		/* 0 = OK, 1 = failed */
 	int foundHeader = 0;	/* found bid history table header */
 	pageInfo_t *pp;
-	int pageType;
+	int pageType = 0;
+	int auctionState = 0;
+	int auctionResult = 0;
 	int got;
+	char *tmpPagename;
+	const char *delim = "_";
+	char *token;
 
 	resetAuctionError(aip);
 
 	if (timeToFirstByte)
 		*timeToFirstByte = getTimeToFirstByte(mp);
 
-	if (pp = getPageInfo(mp)) {
+	if ((pp = getPageInfo(mp))) {
 		if (pp->srcId && !strcmp(pp->srcId, "Captcha.xsl"))
 			return auctionError(aip, ae_captcha, NULL);
 		if (pp->pageName && !strncmp(pp->pageName, "PageViewBids", 12)) {
 			pageType = VIEWBIDS;
+
+			tmpPagename = myStrdup(pp->pageName);
+			/* this must be PageViewBids */
+			token = strtok(tmpPagename, delim);
+			token = strtok(NULL, delim);
+			if(token != NULL)
+			{
+				if(!strcmp(token, "Active")) auctionState = STATE_ACTIVE;
+				else if(strcmp(token, "Closed")) auctionState = STATE_CLOSED;
+				token = strtok(NULL, delim);
+				if(token != NULL)
+				{
+					if(!strcmp(token, "None")) auctionResult = RESULT_NONE;
+					else if(!strcmp(token, "HighBidder")) auctionResult = RESULT_HIGH_BIDDER;
+				}
+			}
+
 			/* bid history or expired/bad auction number */
 			while ((line = getNonTag(mp))) {
 				if (!strcmp(line, "Bid History")) {
@@ -93,12 +124,12 @@ parseBidHistory(memBuf_t *mp, auctionInfo *aip, time_t start, time_t *timeToFirs
 		} else if (pp->pageName && !strcmp(pp->pageName, "PageSignIn")) {
 			return auctionError(aip, ae_mustsignin, NULL);
 		} else {
-			bugReport("parseBidHistory", __FILE__, __LINE__, aip, mp, "unknown pagename");
+			bugReport("parseBidHistory", __FILE__, __LINE__, aip, mp, optiontab, "unknown pagename");
 			return auctionError(aip, ae_notitle, NULL);
 		}
 	} else {
 		log(("parseBidHistory(): pageinfo is NULL\n"));
-		bugReport("parseBidHistory", __FILE__, __LINE__, aip, mp, "pageInfo is NULL");
+		bugReport("parseBidHistory", __FILE__, __LINE__, aip, mp, optiontab, "pageInfo is NULL");
 		return auctionError(aip, ae_notitle, NULL);
 	}
 
@@ -112,12 +143,12 @@ parseBidHistory(memBuf_t *mp, auctionInfo *aip, time_t start, time_t *timeToFirs
 		line = getNonTag(mp);	/* number */
 		if (!line) {
 			log(("parseBidHistory(): No item number"));
-			bugReport("parseBidHistory", __FILE__, __LINE__, aip, mp, "no item number");
+			bugReport("parseBidHistory", __FILE__, __LINE__, aip, mp, optiontab, "no item number");
 			return auctionError(aip, ae_baditem, NULL);
 		}
 	} else {
 		log(("parseBidHistory(): BHitemNo not found"));
-		bugReport("parseBidHistory", __FILE__, __LINE__, aip, mp, "no item number");
+		bugReport("parseBidHistory", __FILE__, __LINE__, aip, mp, optiontab, "no item number");
 		return auctionError(aip, ae_baditem, NULL);
 	}
 	if (debugMode) {
@@ -126,7 +157,7 @@ parseBidHistory(memBuf_t *mp, auctionInfo *aip, time_t start, time_t *timeToFirs
 	} else {
 		if (strcmp(aip->auction, line)) {
 			log(("parseBidHistory(): auction number %s does not match given number %s", line, aip->auction));
-			bugReport("parseBidHistory", __FILE__, __LINE__, aip, mp, "mismatched item number");
+			bugReport("parseBidHistory", __FILE__, __LINE__, aip, mp, optiontab, "mismatched item number");
 			return auctionError(aip, ae_baditem, NULL);
 		}
 	}
@@ -142,12 +173,12 @@ parseBidHistory(memBuf_t *mp, auctionInfo *aip, time_t start, time_t *timeToFirs
 		line = getNonTag(mp);	/* title */
 		if (!line) {
 			log(("parseBidHistory(): No item title"));
-			bugReport("parseBidHistory", __FILE__, __LINE__, aip, mp, "item title not found");
+			bugReport("parseBidHistory", __FILE__, __LINE__, aip, mp, optiontab, "item title not found");
 			return auctionError(aip, ae_baditem, NULL);
 		}
 	} else {
 		log(("parseBidHistory(): BHitemTitle not found"));
-		bugReport("parseBidHistory", __FILE__, __LINE__, aip, mp, "item title or description not found");
+		bugReport("parseBidHistory", __FILE__, __LINE__, aip, mp, optiontab, "item title or description not found");
 		return auctionError(aip, ae_baditem, NULL);
 	}
 	free(aip->title);
@@ -174,13 +205,13 @@ parseBidHistory(memBuf_t *mp, auctionInfo *aip, time_t start, time_t *timeToFirs
 
 			line = getNonTag(mp);
 			if (!line) {
-				bugReport("parseBidHistory", __FILE__, __LINE__, aip, mp, "item price not found");
+				bugReport("parseBidHistory", __FILE__, __LINE__, aip, mp, optiontab, "item price not found");
 				return auctionError(aip, ae_noprice, NULL);
 			}
 			log(("Currently: %s\n", line));
 			aip->price = atof(priceFixup(line, aip));
 			if (aip->price < 0.01) {
-				bugReport("parseBidHistory", __FILE__, __LINE__, aip, mp, "item price could not be converted");
+				bugReport("parseBidHistory", __FILE__, __LINE__, aip, mp, optiontab, "item price could not be converted");
 				return auctionError(aip, ae_convprice, line);
 			}
 			got |= PRICE;
@@ -194,14 +225,14 @@ parseBidHistory(memBuf_t *mp, auctionInfo *aip, time_t start, time_t *timeToFirs
 		} else if (!strcasecmp(line, "Quantity:")) {
 			line = getNonTag(mp);
 			if (!line) {
-				bugReport("parseBidHistory", __FILE__, __LINE__, aip, mp, "item quantity not found");
+				bugReport("parseBidHistory", __FILE__, __LINE__, aip, mp, optiontab, "item quantity not found");
 				return auctionError(aip, ae_noquantity, NULL);
 			}
 			errno = 0;
 			if (isdigit(*line)) {
 				aip->quantity = (int)strtol(line, NULL, 10);
 				if (aip->quantity < 0 || (aip->quantity == 0 && errno == EINVAL)) {
-					bugReport("parseBidHistory", __FILE__, __LINE__, aip, mp, "item quantity could not be converted");
+					bugReport("parseBidHistory", __FILE__, __LINE__, aip, mp, optiontab, "item quantity could not be converted");
 					return auctionError(aip, ae_noquantity, NULL);
 				}
 			} else
@@ -236,7 +267,7 @@ parseBidHistory(memBuf_t *mp, auctionInfo *aip, time_t start, time_t *timeToFirs
 			free(aip->remainRaw);
 			aip->remainRaw = myStrdup("");
 			aip->remain = 1;
-                }
+		}
 		if (!strcasecmp(aip->remainRaw, "Refresh")) {
 			/* Refresh is the label on the next button.  If we
 			 * see this, time left must be empty.  Assume 1 second.
@@ -253,11 +284,11 @@ parseBidHistory(memBuf_t *mp, auctionInfo *aip, time_t start, time_t *timeToFirs
 		} else
 			aip->remain = getSeconds(aip->remainRaw);
 		if (aip->remain < 0) {
-			bugReport("parseBidHistory", __FILE__, __LINE__, aip, mp, "remaining time could not be converted");
+			bugReport("parseBidHistory", __FILE__, __LINE__, aip, mp, optiontab, "remaining time could not be converted");
 			return auctionError(aip, ae_badtime, aip->remainRaw);
 		}
 	} else {
-		bugReport("parseBidHistory", __FILE__, __LINE__, aip, mp, "remaining time not found");
+		bugReport("parseBidHistory", __FILE__, __LINE__, aip, mp, optiontab, "remaining time not found");
 		return auctionError(aip, ae_notime, NULL);
 	}
 	printLog(stdout, "Time remaining: %s (%ld seconds)\n", aip->remainRaw, aip->remain);
@@ -290,8 +321,8 @@ parseBidHistory(memBuf_t *mp, auctionInfo *aip, time_t start, time_t *timeToFirs
 				aip->quantityBid = 0;
 				aip->price = 0;
 				printf("# of bids: %d\n"
-				       "Currently: --  (your maximum bid: %s)\n",
-				       aip->bids, aip->bidPriceStr);
+					"Currently: --  (your maximum bid: %s)\n",
+					aip->bids, aip->bidPriceStr);
 				if (*options.username)
 					printf("High bidder: -- (NOT %s)\n", options.username);
 				else
@@ -312,12 +343,14 @@ parseBidHistory(memBuf_t *mp, auctionInfo *aip, time_t start, time_t *timeToFirs
 	 *		"Bidder"
 	 *		"Bid Amount"
 	 *		"Bid Time"
+	 *		"Action" (sometimes)
 	 *		""
 	 *	    For each bid:
 	 *			""
 	 *			<user>
 	 *			<amount>
 	 *			<date>
+	 *			[links for feedback and other actions] (sometimes)
 	 *			""
 	 *	    (plus multiple rows of 1 column between entries)
 	 *
@@ -406,7 +439,7 @@ parseBidHistory(memBuf_t *mp, auctionInfo *aip, time_t start, time_t *timeToFirs
 		freeTableRow(row);
 	}
 	if (!foundHeader) {
-		bugReport("parseBidHistory", __FILE__, __LINE__, aip, mp, "Cannot find bid table header");
+		bugReport("parseBidHistory", __FILE__, __LINE__, aip, mp, optiontab, "Cannot find bid table header");
 		return auctionError(aip, ae_nohighbid, NULL);
 	}
 
@@ -430,31 +463,82 @@ parseBidHistory(memBuf_t *mp, auctionInfo *aip, time_t start, time_t *timeToFirs
 			aip->bids = 0;
 			aip->price = 0;
 			printf("# of bids: %d\n"
-			       "Currently: --  (your maximum bid: %s)\n",
-			       aip->bids, aip->bidPriceStr);
+				"Currently: --  (your maximum bid: %s)\n",
+				aip->bids, aip->bidPriceStr);
 			if (*options.username)
 				printf("High bidder: -- (NOT %s)\n", options.username);
 			else
 				printf("High bidder: --\n");
 		} else {
-			bugReport("parseBidHistory", __FILE__, __LINE__, aip, mp, "Unrecognized bid table line");
-			ret = auctionError(aip, ae_nohighbid, NULL);
+			if (checkPageType(aip, pageType, auctionState, auctionResult) != 0)
+			{
+				bugReport("parseBidHistory", __FILE__, __LINE__, aip, mp, optiontab, "Unrecognized bid table line");
+				ret = auctionError(aip, ae_nohighbid, NULL);
+			}
 		}
 		freeTableRow(row);
 		free(s);
 		break;
 	    }
 
+	case 6:	/* purchase or maybe single auction */
+		/* this case is before 5 because we will fall through if we know
+		 * this is a normal auction.
+		 */
+	    if(pageType != VIEWBIDS)
+	    {
+			char *currently = getNonTagFromString(row[2]);
+
+			aip->bids = 0;
+			aip->quantityBid = 0;
+			aip->won = 0;
+			aip->winning = 0;
+			/* find your purchase, count number of purchases */
+			/* blank, user, price, quantity, date, blank */
+			for (; row; row = getTableRow(mp)) {
+				if (numColumns(row) == 6) {
+					int quantity = getIntFromString(row[3]);
+					char *bidder;
+
+					++aip->bids;
+					aip->quantityBid += quantity;
+					bidder = getNonTagFromString(row[1]);
+					if (!strcasecmp(bidder, options.username))
+						aip->won = aip->winning = quantity;
+					free(bidder);
+				}
+				freeTableRow(row);
+			}
+			printf("# of bids: %d\n", aip->bids);
+			printf("Currently: %s  (your maximum bid: %s)\n",
+				currently, aip->bidPriceStr);
+			free(currently);
+			switch (aip->winning) {
+			case 0:
+				if (*options.username)
+					printLog(stdout, "High bidder: various purchasers (NOT %s)\n", options.username);
+				else
+					printLog(stdout, "High bidder: various purchasers\n");
+				break;
+			case 1:
+				printLog(stdout, "High bidder: %s!!!\n", options.username);
+				break;
+			default:
+				printLog(stdout, "High bidder: %s!!! (%d items)\n", options.username, aip->winning);
+				break;
+			}
+			break;
+	    }
+	    /* FALLTHROUGH */
 	case 5: /* single auction with bids */
 	    {
 		/* blank, user, price, date, blank */
 		char *winner = getNonTagFromString(row[1]);
-                if(!strcasecmp(winner, "Member Id:"))
-                {
-                   winner = getNthNonTagFromString(row[1], 2);
-                }
 		char *currently = getNonTagFromString(row[2]);
 
+		if (!strcasecmp(winner, "Member Id:"))
+		   winner = getNthNonTagFromString(row[1], 2);
+
 		aip->quantityBid = 1;
 
 		/* current price */
@@ -462,7 +546,12 @@ parseBidHistory(memBuf_t *mp, auctionInfo *aip, time_t start, time_t *timeToFirs
 		if (aip->price < 0.01) {
 			free(winner);
 			free(currently);
-			bugReport("parseBidHistory", __FILE__, __LINE__, aip, mp, "bid price could not be converted");
+			if (checkPageType(aip, pageType, auctionState, auctionResult) == 0)
+			{
+				freeTableRow(row);
+				break;
+			}
+			bugReport("parseBidHistory", __FILE__, __LINE__, aip, mp, optiontab, "bid price could not be converted");
 			return auctionError(aip, ae_convprice, currently);
 		}
 		printLog(stdout, "Currently: %s  (your maximum bid: %s)\n",
@@ -520,50 +609,6 @@ parseBidHistory(memBuf_t *mp, auctionInfo *aip, time_t start, time_t *timeToFirs
 		free(winner);
 		break;
 	    }
-	case 6:	/* purchase */
-	    {
-		char *currently = getNonTagFromString(row[2]);
-
-		aip->bids = 0;
-		aip->quantityBid = 0;
-		aip->won = 0;
-		aip->winning = 0;
-		/* find your purchase, count number of purchases */
-		/* blank, user, price, quantity, date, blank */
-		for (; row; row = getTableRow(mp)) {
-			if (numColumns(row) == 6) {
-				int quantity = getIntFromString(row[3]);
-				char *bidder;
-
-				++aip->bids;
-				aip->quantityBid += quantity;
-				bidder = getNonTagFromString(row[1]);
-				if (!strcasecmp(bidder, options.username))
-					aip->won = aip->winning = quantity;
-				free(bidder);
-			}
-			freeTableRow(row);
-		}
-		printf("# of bids: %d\n", aip->bids);
-		printf("Currently: %s  (your maximum bid: %s)\n",
-		       currently, aip->bidPriceStr);
-		free(currently);
-		switch (aip->winning) {
-		case 0:
-			if (*options.username)
-				printLog(stdout, "High bidder: various purchasers (NOT %s)\n", options.username);
-			else
-				printLog(stdout, "High bidder: various purchasers\n");
-			break;
-		case 1:
-			printLog(stdout, "High bidder: %s!!!\n", options.username);
-			break;
-		default:
-			printLog(stdout, "High bidder: %s!!! (%d items)\n", options.username, aip->winning);
-			break;
-		}
-		break;
-	    }
 	case 7: /* dutch with bids */
 	    {
 		int wanted = 0;
@@ -600,7 +645,7 @@ parseBidHistory(memBuf_t *mp, auctionInfo *aip, time_t start, time_t *timeToFirs
 			aip->won = aip->winning;
 		printf("# of bids: %d\n", aip->bids);
 		printf("Currently: %s  (your maximum bid: %s)\n",
-		       currently, aip->bidPriceStr);
+			currently, aip->bidPriceStr);
 		free(currently);
 		if (aip->winning > 0) {
 			if (aip->winning == wanted)
@@ -616,8 +661,11 @@ parseBidHistory(memBuf_t *mp, auctionInfo *aip, time_t start, time_t *timeToFirs
 		break;
 	    }
 	default:
-		bugReport("parseBidHistory", __FILE__, __LINE__, aip, mp, "%d columns in bid table", numColumns(row));
-		ret = auctionError(aip, ae_nohighbid, NULL);
+		if (checkPageType(aip, pageType, auctionState, auctionResult) != 0)
+		{
+			bugReport("parseBidHistory", __FILE__, __LINE__, aip, mp, optiontab, "%d columns in bid table", numColumns(row));
+			ret = auctionError(aip, ae_nohighbid, NULL);
+		}
 		freeTableRow(row);
 	}
 
@@ -644,8 +692,8 @@ getSeconds(char *timestr)
 	 * the auction is over, or it still running with less than 1 second.
 	 * I'll make the safer assumption and say that there is 1 second
 	 * remaining.
-         * bomm: The transition seems to have changed to "--". I will accept
-         * any string starting with "--".
+	 * bomm: The transition seems to have changed to "--". I will accept
+	 * any string starting with "--".
 	 */
 	if (!*timestr || !strncmp(timestr, "--", 2))
 		return 1;
@@ -671,3 +719,79 @@ getSeconds(char *timestr)
 
 	return accum;
 }
+/* This function is called when we could not successfully parse the bids
+ * or purchases table.
+ *
+ * If we can find out the result based on the auction state and result codes
+ * the result will be written to the auctionInfo structure and the return
+ * code will be 0.
+ * If we cannot find out the result the return code will be != 0.
+ *
+ */
+static int checkPageType(auctionInfo *aip, int pageType, int auctionState, int auctionResult)
+{
+	if((pageType == 0) || (auctionState == 0) || (auctionResult == 0)) return -1;
+
+	switch(pageType)
+	{
+	case VIEWBIDS:
+		switch(auctionState)
+		{
+		case STATE_ACTIVE:
+			switch(auctionResult)
+			{
+			case RESULT_HIGH_BIDDER:
+				/* assume we have bid on one item */
+				aip->quantityBid = 1;
+				aip->winning = 1;
+				aip->won = 0;
+				aip->quantity = 0;
+				printLog(stdout, "High bidder: %s!!!\n", options.username);
+				break;
+			case RESULT_NONE:
+				aip->quantityBid = 0;
+				aip->winning = 0;
+				aip->won = 0;
+				aip->quantity = 0;
+				printLog(stdout, "High bidder: (unknown) (NOT %s)\n",
+						 options.username);
+			default:
+				return -1;
+			}
+		case STATE_CLOSED:
+			switch(auctionResult)
+			{
+			case RESULT_HIGH_BIDDER:
+				/* assume we have bid on one item */
+				aip->quantityBid = 1;
+				aip->winning = 1;
+				aip->won = 1;
+				aip->quantity = 1;
+				printLog(stdout, "High bidder: %s!!!\n", options.username);
+				break;
+			case RESULT_NONE:
+				aip->quantityBid = 0;
+				aip->winning = 0;
+				aip->won = 0;
+				aip->quantity = 0;
+				printLog(stdout, "High bidder: (unknown) (NOT %s)\n",
+						 options.username);
+				break;
+			default:
+				return -1;
+			}
+			break;
+		default:
+			/* unknown state */
+			return -1;
+		}
+		break;
+	case VIEWTRANSACTIONS:
+		/* currently we cannot handle this other than parsing the table */
+		return -1;
+		break;
+	default:
+		return -1;
+	}
+	return 0;
+}
